OC.L10N.register(
    "user_openid_provider",
    {
    "OpenID Provider remembered sites" : "Þekktar OpenID-veitur",
    "Trusted" : "Treyst",
    "Denied" : "Hafnað",
    "Remove" : "Fjarlægja"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
